Learn R Programming

corehunter (version 3.0.1)

coreHunterData: Initialize Core Hunter data.

Description

The data may contain genotypes, phenotypes and/or a precomputed distance matrix. All provided data should describe the same individuals which is verified by comparing the item ids and names.

Usage

coreHunterData(genotypes, phenotypes, distances)

Arguments

genotypes
Genetic marker data (chgeno).
phenotypes
Phenotypic trait data (chpheno).
distances
Precomputed distance matrix (chdist).

Value

Core Hunter data (chdata) with elements
Core Hunter data of class chdata.

See Also

genotypes, phenotypes, distances

Examples

Run this code
geno.file <- system.file("extdata", "genotypes.csv", package = "corehunter")
pheno.file <- system.file("extdata", "phenotypes.csv", package = "corehunter")
dist.file <- system.file("extdata", "distances.csv", package = "corehunter")

my.data <- coreHunterData(
  genotypes(file = geno.file),
  phenotypes(file = pheno.file),
  distances(file = dist.file)
)

Run the code above in your browser using DataLab