Learn R Programming

corehunter (version 3.0.1)

exampleData: Example dataset with 218 individuals.

Description

Includes a precomputed distance matrix read from "extdata/distances.csv", genotypes read from "extdata/genotypes.csv" and phenotypes read from "extdata/phenotypes.csv".

Usage

exampleData()

Arguments

Value

Core Hunter data of class chdata

Cerón-Rojas, J. Jesús ; Crossa, José; Arief, Vivi N.; Kaye Basford; Rutkoski, Jessica; Jarquín, Diego ; Alvarado, Gregorio; Beyene, Yoseph; Semagn, Kassa ; DeLacy, Ian, 2015-06-04, "Application of a Genomics Selection Index to Real and Simulated Data", http://hdl.handle.net/11529/10199 V10

Details

The distance matrix is computed from the genotypes (Modified Rogers' distance). Data was taken from the CIMMYT Research Data Repository (Study Global ID hdl:11529/10199; real data set 5, cycle 0).