Rdocumentation
powered by
Learn R Programming
corehunter (version 3.0.1)
wrapData: Wrap distances, genotypes or phenotypes in Core Hunter data.
Description
If the given data does not match any of these three classes it is returned unchanged.
Usage
wrapData(data)
Arguments
data
of class
chgeno
,
chpheno
or
chdist
Value
Core Hunter data of class
chdata