read.delim where the separator is inferred from the file extension (CSV or TXT).
For CSV files the delimiter is set to "," while for TXT file "\t" is used. Also sets
some default argument values as used by Core Hunter.
read.autodelim(file, row.names = 1, check.names = FALSE, stringsAsFactors = FALSE, strip.white = TRUE, ...) If there is a header and the first row contains one fewer field than
the number of columns, the first column in the input is used for the
row names. Otherwise if row.names is missing, the rows are
numbered.
Using row.names = NULL forces row numbering. Missing or
NULL row.names generate row names that are considered
to be automatic (and not preserved by as.matrix).
TRUE then the names of the
variables in the data frame are checked to ensure that they are
syntactically valid variable names. If necessary they are adjusted
(by make.names) so that they are, and also to ensure
that there are no duplicates.as.is and
colClasses, both of which allow finer control.sep has
been specified, and allows the stripping of leading and trailing
white space from unquoted character fields (numeric fields
are always stripped). See scan for further details
(including the exact meaning of white space),
remembering that the columns may include the row names.read.delim.